@@ -122,10 +122,14 @@ class PostgresRelationalDatabaseService:
     """
     Useful class to manage the specific relational database service for postgres
 
+    Args:
+        schema (str): are analogous to directories at the operating system level, except that schemas cannot be nested.
+    
     Attributes:
         connection (Any): database connection
     """
-    def __init__(self) -> None:
+    def __init__(self, schema: str = 'public') -> None:
+        self._schema = schema
         self._connection = psycopg2.connect(
             user=os.getenv("DB_USER"),
             password=os.getenv("DB_PASSWORD"),
@@ -157,7 +161,7 @@ class PostgresRelationalDatabaseService:
     def get_column(self, table_name:str, return_column:str, condition_column:str, condition_value:Any) -> Any:
         with self._connection.cursor() as cursor:
             cursor.execute(
-                query=f'SELECT {return_column} FROM {table_name} WHERE {condition_column} = %s;',
+                query=f'SELECT {return_column} FROM {self._schema}.{table_name} WHERE {condition_column} = %s;',
                 vars=(condition_value,)
             )
 
@@ -180,7 +184,7 @@ class PostgresRelationalDatabaseService:
         """
         with self._connection.cursor() as cursor:
             cursor.execute(
-                query=f'UPDATE {table_name} SET {update_column} = %s WHERE {condition_column} = %s;',
+                query=f'UPDATE {self._schema}.{table_name} SET {update_column} = %s WHERE {condition_column} = %s;',
                 vars=(update_value, condition_value)
             )
             self._connection.commit()
@@ -202,7 +206,7 @@ class PostgresRelationalDatabaseService:
 
         with self._connection.cursor() as cursor:
             cursor.execute(
-                query=f'INSERT INTO {table_name} ({keys}) VALUES ({typed_key}) RETURNING {return_column};',
+                query=f'INSERT INTO {self._schema}.{table_name} ({keys}) VALUES ({typed_key}) RETURNING {return_column};',
                 vars=values
             )
             return_value = cursor.fetchone()[0]
@@ -222,7 +226,7 @@ class PostgresRelationalDatabaseService:
         keys, _, typed_key = self._convert_columns_to_tuple(column_name)
         with self._connection.cursor() as cursor:
             cursor.executemany(
-                query=f'INSERT INTO {table_name} ({keys}) VALUES ({typed_key});', 
+                query=f'INSERT INTO {self._schema}.{table_name} ({keys}) VALUES ({typed_key});', 
                 vars_list=values
             )
             self._connection.commit()
@@ -235,7 +239,7 @@ class PostgresRelationalDatabaseService:
 
         with self._connection.cursor() as cursor:
             cursor.execute(
-                query=f'DELETE FROM {table_name} {where};',
+                query=f'DELETE FROM {self._schema}.{table_name} {where};',
                 vars=()
             )
             self._connection.commit()
