@@ -1,5 +1,8 @@
+import cv2
 import numpy as np
 
+from typing import Any
+
 
 def to_image(image:np.ndarray) -> np.ndarray:
     """
@@ -13,6 +16,18 @@ def to_image(image:np.ndarray) -> np.ndarray:
     """
     return np.asarray(image).astype(np.uint8)
 
+def to_ndarray(bytes:Any) -> np.ndarray:
+    """
+    Method to convert an bytes to an array
+
+    Parameters:
+        bytes (Any): bytes array
+
+    Returns:
+        np.ndarray: convert a list of bytes to an np.ndarray
+    """
+    return cv2.imdecode(np.asarray(bytearray(bytes)), cv2.IMREAD_COLOR)
+
 def crop(image:np.ndarray, x:int, y:int, w:int, h:int) -> np.ndarray:
     """
     Method to crop the image
